@@ -36,7 +36,7 @@ def get_many(db_client, query_string):
             return None
 
         else:
-            print("GET MANY RESULT: " + json.dumps(result))
+            #print("GET MANY RESULT: " + json.dumps(result))
             return result
 
     except (Exception, pg8000.DatabaseError) as error:
@@ -87,7 +87,7 @@ def get_many_list(db_client, query_list):
                 return False
 
         else:
-            print("GET MANY RESULT: " + json.dumps(result_list))
+            #print("GET MANY RESULT: " + json.dumps(result_list))
             return result_list
 
     except (Exception, pg8000.DatabaseError) as error:
